# /**
#
# \name{colorramp}
#
# \title{colorramp}
#
# \alias{colorramp}
#
# \keyword{color}
#
# \description{Returns a function which allows to create color ramps.}
#
# \value{A function with a single argument n to specify the length of the
#        desired color ramp.}
#
#
# \arguments{
#  \item{palette}{vector, defining a color palette}
# }
# 
# \examples{
#   RdBu11 <- c("#67001F", "#B2182B", "#D6604D", "#F4A582", "#FDDBC7",
#               "#F7F7F7", "#D1E5F0", "#92C5DE", "#4393C3", "#2166AC", "#053061")
#   finerGraded <- colorramp(RdBu11)(33)
#   barplot(rep(1,33), col=finerGraded)
#	}
#
# \author{}
# */

colorramp = function (palette)  {
  coord <- as.data.frame(t(col2rgb(palette))/255)
  x <- seq(0, 1, length = length(palette))
  r <- approxfun(x, coord$red)
  g <- approxfun(x, coord$green)
  b <- approxfun(x, coord$blue)
  function(n) {
    x <- seq(0, 1, length = n)
    rgb(r(x), g(x), b(x))
  }
}
