# /**
#
# \name{shorth}
#
# \title{shorth}
#
# \alias{shorth}
#
# \keyword{univar}
#
# \description{
#
# Given a sample of real values, find the midpoint of the "shorth"
#
# Let f be the empirical distribution function, and w be the width of
# the shorth (typically 0.5). Find q that minimizes
#
#                       \deqn{f^{-1}(q+w)  - f^{-1}(q)}{
#                             f^{-1}(q+w)  - f^{-1}(q) }
#
#}
#
# \value{}
#
# \arguments{
#  \item{z}{}
# }
# 
# \details{}
#
# \examples{
#	}
#
# \author{}
# */
shorth <- function(z) {
  sz    <- sort(z)
  width <- round(0.5*length(z))
  diffs <- sz[(width+1):length(z)] - sz[1:(length(z)-width)]
  q     <- which(diffs==min(diffs))

  # deal with ties: if they lie within 5%, simply take the average
  # otherwise, generate an error 
  if (max(q)-min(q) <= 0.05*length(z)) {
    q <- mean(q)
  } else {
    stop(paste("Error in shorth.r: found more than one q: ", q, "\n", sz[q], "\n", sz[q+width], "\n"))
  }
  return(mean(sz[q:(q+width-1)]))
}
